Development Status
*******************

Current
----------

This project is in active development and is currently a working alpha release. Classes and Methods are being refactored as things grow so the codebase is moving around quite a bit. 

Python 2 support
"""""""""""""""""

The code is written for python 3, every minor relase we'll be porting the code back to python 2, the installer will install the appropriate code based on the environment you're installing into.   



Testing
""""""""""

Each commit on dev and master is built and tested on a continious integration server for python2.6, python2.7 and python3.2 currently these are simple nosetests coving core functionality, but these will be expanded as well. 


Future
--------

I'll treat Release 0.5 as a beta release, I expect to reach that point in mid January 2012 assuming the code stabilizes and a few more major features get added. 

